==> nrbc-1.3-sources.jar: org/example/prefect/PutCODinplaceResponse.java <==

package org.example.prefect;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="doneStart" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="place" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="type" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="seriousness" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "doneStart",
    "place",
    "type",
    "seriousness"
})
@XmlRootElement(name = "putCODinplaceResponse")
public class PutCODinplaceResponse {

    @XmlElement(required = true)
    protected String doneStart;
    @XmlElement(required = true)
    protected String place;
    @XmlElement(required = true)
    protected String type;
    @XmlElement(required = true)
    protected String seriousness;

    /**
     * Gets the value of the doneStart property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDoneStart() {
        return doneStart;
    }

    /**
     * Sets the value of the doneStart property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDoneStart(String value) {
        this.doneStart = value;
    }

    /**
     * Gets the value of the place property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPlace() {
        return place;
    }

    /**
     * Sets the value of the place property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPlace(String value) {
        this.place = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setType(String value) {
        this.type = value;
    }

    /**
     * Gets the value of the seriousness property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSeriousness() {
        return seriousness;
    }

    /**
     * Sets the value of the seriousness property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSeriousness(String value) {
        this.seriousness = value;
    }

}

==> nrbc-1.4-sources.jar: org/example/prefect/PutCODinplaceResponse.java <==

package org.example.prefect;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang.builder.ToStringBuilder;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.builder.JAXBToStringBuilder;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="doneStart" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="place" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="type" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="seriousness" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "doneStart",
    "place",
    "type",
    "seriousness"
})
@XmlRootElement(name = "putCODinplaceResponse")
public class PutCODinplaceResponse
    implements ToString
{

    @XmlElement(required = true)
    protected String doneStart;
    @XmlElement(required = true)
    protected String place;
    @XmlElement(required = true)
    protected String type;
    @XmlElement(required = true)
    protected String seriousness;

    /**
     * Gets the value of the doneStart property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDoneStart() {
        return doneStart;
    }

    /**
     * Sets the value of the doneStart property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDoneStart(String value) {
        this.doneStart = value;
    }

    /**
     * Gets the value of the place property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPlace() {
        return place;
    }

    /**
     * Sets the value of the place property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPlace(String value) {
        this.place = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setType(String value) {
        this.type = value;
    }

    /**
     * Gets the value of the seriousness property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSeriousness() {
        return seriousness;
    }

    /**
     * Sets the value of the seriousness property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSeriousness(String value) {
        this.seriousness = value;
    }

    public void toString(ToStringBuilder toStringBuilder) {
        {
            String theDoneStart;
            theDoneStart = this.getDoneStart();
            toStringBuilder.append("doneStart", theDoneStart);
        }
        {
            String thePlace;
            thePlace = this.getPlace();
            toStringBuilder.append("place", thePlace);
        }
        {
            String theType;
            theType = this.getType();
            toStringBuilder.append("type", theType);
        }
        {
            String theSeriousness;
            theSeriousness = this.getSeriousness();
            toStringBuilder.append("seriousness", theSeriousness);
        }
    }

    public String toString() {
        final ToStringBuilder toStringBuilder = new JAXBToStringBuilder(this);
        toString(toStringBuilder);
        return toStringBuilder.toString();
    }

}
